<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Congratulations</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <link rel="stylesheet" href="{{ url_for('static', filename='styles.css') }}">
</head>
<body class="potato-page-center">
    <div class="potato-page-card" style="text-align: center;">
        <div class="potato-page-icon potato-page-icon-success">
            <i class="fas fa-check"></i>
        </div>
        <h1 class="potato-page-title">{{grat_msg}}</h1>
        <p class="potato-page-subtitle">Redirecting in a moment...</p>
    </div>
</body>
</html>
