"""
Potato Integrations

Third-party integrations for connecting external ML frameworks
to Potato's annotation platform.

Available integrations:
- LangChain callback handler: Auto-send LangChain traces to Potato
"""
